@@ -119,7 +119,7 @@ void KNetworkConf::loadNetworkDevicesInfo()
             item->setPixmap(0,activeWirelessDeviceImg);
 
           item->setText(3,i18n("Enabled"));
-          item->setPixmap(3,SmallIcon("ok"));
+          item->setPixmap(3,SmallIcon("dialog-ok"));
         }
         else
         {
@@ -716,7 +716,7 @@ void KNetworkConf::verifyDeviceStateChanged(){
           item->setPixmap(0,activeWirelessDeviceImg);
 
         item->setText(3,i18n("Enabled"));
-        item->setPixmap(3,SmallIcon("ok"));
+        item->setPixmap(3,SmallIcon("dialog-ok"));
 //        config->runDetectionScript(netInfo->getPlatformName());
         config->listIfaces(netInfo->getPlatformName());
 //        item->setText(1,dev->getIpAddress());
